pub struct DodbConnection { /* private fields */ }Implementations
Sourceimpl DodbConnection
impl DodbConnection
Sourcepub async fn connect(
bind_addr: SocketAddr,
server_addr: SocketAddr,
server_name: &str,
tls: ClientTlsConfig,
limits: ProtocolLimits,
) -> Result<Self, ClientError>
pub async fn connect( bind_addr: SocketAddr, server_addr: SocketAddr, server_name: &str, tls: ClientTlsConfig, limits: ProtocolLimits, ) -> Result<Self, ClientError>
Opens one authenticated QUIC connection that can serve any number of tenant-scoped handles.
pub async fn connect_with_endpoint( endpoint: Endpoint, server_addr: SocketAddr, server_name: &str, tls: ClientTlsConfig, limits: ProtocolLimits, ) -> Result<Self, ClientError>
Sourcepub fn connect_lazy(
bind_addr: SocketAddr,
server_addr: SocketAddr,
server_name: &str,
tls: ClientTlsConfig,
limits: ProtocolLimits,
) -> Result<Self, ClientError>
pub fn connect_lazy( bind_addr: SocketAddr, server_addr: SocketAddr, server_name: &str, tls: ClientTlsConfig, limits: ProtocolLimits, ) -> Result<Self, ClientError>
Creates a shared connection manager without dialing until its first request.
Sourcepub fn connect_lazy_with_endpoint(
endpoint: Endpoint,
server_addr: SocketAddr,
server_name: &str,
tls: ClientTlsConfig,
limits: ProtocolLimits,
) -> Result<Self, ClientError>
pub fn connect_lazy_with_endpoint( endpoint: Endpoint, server_addr: SocketAddr, server_name: &str, tls: ClientTlsConfig, limits: ProtocolLimits, ) -> Result<Self, ClientError>
Creates a shared connection manager around an existing endpoint without dialing until its first request.
pub fn for_tenant(&self, tenant: TenantId) -> DodbClient
pub fn remote_addr(&self) -> SocketAddr